/*  This file is part of FediPotato.
 *  Copyright © 2020 tastytea <tastytea@tastytea.de>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, version 3.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FEDIPOTATO_HPP
#define FEDIPOTATO_HPP

#include <string_view>

/*!
 *  @brief  High-level interface to fediverse accounts and their data.
 *
 *  @since  0.1.0
 */
namespace FediPotato
{

using std::string_view;

class FediPotato
{
public:
    //! Default constructor
    FediPotato() = default;

    //! Copy constructor
    FediPotato(const FediPotato &other) = default;

    //! Move constructor
    FediPotato(FediPotato &&other) noexcept = default;

    //! Destructor
    virtual ~FediPotato() noexcept = default;

    //! Copy assignment operator
    FediPotato& operator=(const FediPotato &other) = default;

    //! Move assignment operator
    FediPotato& operator=(FediPotato &&other) noexcept = default;

    /*!
     *  @brief  Return the version.
     *
     *  @since  0.1.0
     */
    static string_view get_version();
};

} // namespace FediPotato

#endif  // FEDIPOTATO_HPP
